==> camel-spring-boot-2.22.0-sources.jar: org/apache/camel/spring/boot/health/HealthCheckServiceConfiguration.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.boot.health;

import java.util.HashMap;
import java.util.Map;

import org.springframework.boot.context.properties.ConfigurationProperties;

@ConfigurationProperties(prefix = HealthConstants.HEALTH_CHECK_SERVICE_PREFIX)
public class HealthCheckServiceConfiguration {
    /**
     * Global option to enable/disable this ${@link org.apache.camel.health.HealthCheckService}, default is false.
     */
    private boolean enabled;

    /**
     * The interval between checks.
     */
    private String checkInterval;

    /**
     * Checks configuration.s
     */
    private Map<String, Check> checks = new HashMap<>();

    public boolean isEnabled() {
        return enabled;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }

    public String getCheckInterval() {
        return checkInterval;
    }

    public void setCheckInterval(String checkInterval) {
        this.checkInterval = checkInterval;
    }

    public Map<String, Check> getChecks() {
        return checks;
    }

    // *************************************
    // Checks
    // *************************************

    public class Check {
        /**
         * Option for this check.
         */
        private Map<String, Object> options;

        public Map<String, Object> getOptions() {
            return options;
        }

        public void setOptions(Map<String, Object> options) {
            this.options = options;
        }
    }
}

==> camel-spring-boot-2.25.1-sources.jar: org/apache/camel/spring/boot/health/HealthCheckServiceConfiguration.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.boot.health;

import java.util.HashMap;
import java.util.Map;

import org.springframework.boot.context.properties.ConfigurationProperties;

@ConfigurationProperties(prefix = HealthConstants.HEALTH_CHECK_SERVICE_PREFIX)
public class HealthCheckServiceConfiguration {
    /**
     * Global option to enable/disable extended Camel health checks, default is false.
     */
    private boolean enabled;

    /**
     * The interval between checks.
     */
    private String checkInterval;

    /**
     * Configuration of health checks
     */
    private Map<String, Check> checks = new HashMap<>();

    public boolean isEnabled() {
        return enabled;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }

    public String getCheckInterval() {
        return checkInterval;
    }

    public void setCheckInterval(String checkInterval) {
        this.checkInterval = checkInterval;
    }

    public Map<String, Check> getChecks() {
        return checks;
    }

    // *************************************
    // Checks
    // *************************************

    public class Check {
        /**
         * Option for this health check.
         */
        private Map<String, Object> options;

        public Map<String, Object> getOptions() {
            return options;
        }

        public void setOptions(Map<String, Object> options) {
            this.options = options;
        }
    }
}
